gridGaugeChart: Generating Gauge Charts Using Grid

Description History

Description

The package provides a function to plot simple gauge charts. It mimics the features of the flexdashboards-package's gaugeChart function to produce gauge charts for any output device supported by R's standard graphics facilities.

History

0.7

initial beta-version


mlkornexl/gridGaugeChart documentation built on May 12, 2019, 4:26 p.m.