Description Usage Arguments Functions Range Definition Colors
Gaug chart sectors define colored backgrounds for gauge chart axis based on KPI ranges success, warning, and danger.
1 2 3 | gaugeChartSectors(success, warning, danger, colors = c(), rev = FALSE)
.gaugeBeamColor(sectors, x, default = "#808080")
|
success, warning, danger |
numeric, lower and upper limits for KPI ranges success, warning, and danger, see range definition section for details |
colors |
color definition for background of KPI ranges; see colors section for details@details |
rev |
logical, if TRUE, the order of KPI ranges is reverted; see range definition section for the effects |
sectors |
a |
x |
numeric, value of the KPI |
default |
color specification if |
.gaugeBeamColor: With .gaugeBeamColor the background
color of the KPI range (success, warning, or danger)
given by x will be returned.
The sectors will be ordered according to success, warning,
and danger. If rev = TRUE the order will be reverted.
Range definition success, warning, or danger can be
given either as numeric dupel with lower and upper limit. If they are given
by a single number, this will be assumed to be the lower limit.
The respective KPI range for a given value x is calculated according
to:
Select the KPI range with lower bound less or equal to value x
and - if specified - the upper bound greater or equal to value x.
If more than one range is returned with step 1., use the last of the KPI ranges (c.f. ordering of KPI ranges above).
Colors may be specified by a vector of any of the three kinds of R
color specifications, i.e. either a color name (see
colors() for a list of colors), a hexidecimal
string of the form "#rrggbb" or "#rrggbbaa" (see
rgb()), or a positive integer i meaning
palette()[i]. The colors can either be named
according to the KPI ranges or given using the same sequence as the input
of the KPI ranges.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.