The package provides a function to plot simple gauge charts. It mimics the features of the flexdashboards-package's gaugeChart function to produce gauge charts for any output device supported by R's standard graphics facilities.
initial beta-version
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.